package com.caimei.service.products.impl;

import com.caimei.entity.*;
import com.caimei.mapper.products.DetailsMapper;
import com.caimei.mapper.products.HomePageMapper;
import com.caimei.service.products.DetailsService;
import com.caimei.utils.AppUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service
public class DetailsServiceImpl implements DetailsService {
    @Autowired
    private DetailsMapper detailsMapper;
    @Autowired
    private HomePageMapper homePageMapper;
    @Value("${miniprogram.domain}")
    private String domain;

    @Override
    public CmMallOrganizeProducts productDetails(Integer id, Integer userID) {
        //商品信息
        CmMallOrganizeProducts organizeProducts = detailsMapper.findProduct(id);
        CmMallProduct cmMallProduct = detailsMapper.product(organizeProducts.getProductID());
        String[] split = null;
        String tags = "";
        //商品标签
        if (cmMallProduct.getTags() != null) {
            tags = cmMallProduct.getTags();
            tags = tags.replace(" ", ",");
            tags = tags.replace("、", ",");
            tags = tags.replace("，", ",");
            if (tags.contains(",")) {
                split = tags.split(",");
                List<String> list = new ArrayList();
                for (String s : split) {
                    if (s != null && !s.equals("")) list.add(s);
                    split = list.toArray(new String[list.size()]);
                }
            }
        }
        cmMallProduct.setTagsList(split);
        cmMallProduct.setMainImage(AppUtils.getImageURL("cmMallProduct", cmMallProduct.getMainImage(), 0, domain));
        if (cmMallProduct.getStock() == null || cmMallProduct.getStock() == 0) cmMallProduct.setStock(99);
        organizeProducts.setCmMallProduct(cmMallProduct);
        //商品图片
        List<CmMallProductImage> cmMallProductImage = detailsMapper.findAllProductImage(organizeProducts.getProductID());
        for (CmMallProductImage image : cmMallProductImage) {
            String imageURL = AppUtils.getImageURL("cmMallProduct", image.getImage(), 0, domain);
            image.setImage(imageURL);
        }
        organizeProducts.setCmMallProductImage(cmMallProductImage);
        //商品详情
        CmMallProductDetailInfo cmMallProductDetailInfo = detailsMapper.findProductDetail(organizeProducts.getProductID());
        organizeProducts.setCmMallProductDetailInfo(cmMallProductDetailInfo);
        //供应商信息
        CmMallShop cmMallShop = detailsMapper.findShop(cmMallProduct.getShopID());
        if (cmMallShop.getBusinessScope() != null && cmMallShop.getBusinessScope().contains("/")) {
            String[] businessScopeArray = cmMallShop.getBusinessScope().split("/");
            cmMallShop.setBusinessScopeArray(businessScopeArray);
        }
        cmMallShop.setLogo(AppUtils.getImageURL("shopLogo", cmMallShop.getLogo(), 0, domain));
        cmMallShop.setBusinessLicenseImage(AppUtils.getImageURL("shopLogo", cmMallShop.getBusinessLicenseImage(), 0, domain));
        organizeProducts.setCmMallShop(cmMallShop);
        //购物车数量
        Integer count = homePageMapper.cartQuantity(userID);
        if (count == null) count = 0;
        organizeProducts.setCartCount(count);
        return organizeProducts;
    }

    @Override
    public Integer saveCart(CmMallCart cmMallCart) {
        CmMallCart cart = detailsMapper.findCartProduct(cmMallCart);
        if (cart != null) {
            int count = cart.getProductCount() + cmMallCart.getProductCount();
            cart.setProductCount(count);
            cart.setAddTime(new Date());
            detailsMapper.updateCart(cart);
        } else {
            cmMallCart.setAddTime(new Date());
            cmMallCart.setDelFlag("0");
            detailsMapper.saveCart(cmMallCart);
        }
        Integer cartQuantity = homePageMapper.cartQuantity(cmMallCart.getUserID());
        if (cartQuantity == null) cartQuantity = 0;
        return cartQuantity;
    }
}
